#!/bin/bash

FILE="config1.php"

clear

if [ -f $FILE ];
then
echo "Note: You already have a config.php file. DO NOT run this script to upgrade the install.";
echo "If you need to re-create the config.php file, first delete or rename (recommended) the current config.php";
echo "The script will now stop.";
echo -e "\n";
 exit
fi

echo "---------------------------------------------------------------------------";
echo "Linux distro: Please type U for Ubuntu/Debian or C for CentOS/Redhat/Fedora";
echo -n "Distro: ";
read dist;

if [ "$dist" = "U" ]
then
        echo "";
        echo "----------------------";
        echo "Ubuntu/Debian Selected";
        echo "----------------------";
        echo "";
        MYSQL=`which mysql`
        PHP=`which php`
        APACHE=`which apache2`
        ERR='0';
        echo "";

elif [ "$dist" = "u" ]
then
        echo "";
        echo "----------------------";
        echo "Ubuntu/Debian Selected";
        echo "----------------------";
        echo "";
        MYSQL=`which mysql`
        PHP=`which php`
        APACHE=`which apache2`
        ERR='0';
        echo "";

elif [ "$dist" = "C" ]
then
        echo "";
        echo "-----------------------------";
        echo "CentOS/RedHat/Fedora Selected";
        echo "-----------------------------";
        echo "";
        MYSQL=`which mysql`
        PHP=`which php`
        APACHE=`which httpd`
        ERR='0';
        echo "";
elif [ "$dist" = "c" ]
then
        echo "";
        echo "-----------------------------";
        echo "CentOS/RedHat/Fedora Selected";
        echo "-----------------------------";
        echo "";
        MYSQL=`which mysql`
        PHP=`which php`
        APACHE=`which httpd`
        ERR='0';
        echo "";

else
        clear;
        echo "---------------";
        echo "Invalid Selection: "  $dist;
        echo "Please re-run setup script and select U for Ubuntu/Debian or C for CentOS/RedHat/Fedora";
        echo "---------------";
        exit;
fi
echo '-------------';

if [ "$MYSQL" == "" ]; then
  echo "ERROR! MYSQL Does not appear to be installed";
  ERR='1';
else
 echo "MySQL is Installed";
fi

if [ "$APACHE" == "" ]; then
  echo "ERROR! Apache2 Does not appear to be installed";
  ERR='1';
else
 echo "Apache is Installed";
fi

if [ "$PHP" == "" ]; then
  echo "ERROR! PHP5 Does not appear to be installed";
  ERR='1';
else
 echo "PHP is Installed";
fi

echo '-------------';

if [ "$ERR" == "1" ]; then
  echo "";
  echo "---------------------------------";
  echo "FATAL ERROR!!! See above message!";
  echo "Problem must be resolved before installing AssetTrackDB";
  echo "---------------------------------";
  echo "";
exit;
fi

echo -e "\n";
echo -e "\n";
echo "---------------------------";
echo "AssetTrackDB Setup Script";
echo "---------------------------";
echo "This script will ask for the following:";
echo "Database Name";
echo " -- Name of the MySQL Database that AssetTrackDB will use to store data";
echo "";
echo "MySQL Username / Pass";
echo " -- User/Pass that this script will use to connect to your MySQL Server";
echo "";
echo "Next the script will:";
echo "Create Database";
echo "Create Database user";
echo "Create Database Read-Only User";
echo "Import AssetTrackDB database structure";
echo "Create config.php";
echo "";
echo "When complete the AssetTrackDB install is ready to use";
echo "";
echo "NOTE: This script MUST be run from the web directory where AssetTrackDB is installed";
echo "Examples: /var/www/asset/ or /var/www/html/asset/";
echo "";
echo "";
echo "----------------------------------------------------------------------";
echo "";
echo "Note: This is the name of the MySQL Database that AssetTrackDB will use to store data";
echo "Most users should accept the default";
echo "Database Name (AssetDB):";
read dbname;
if [ "$dbname" == "" ]; then
  dbname="AssetDB";
fi

#Randomly Generatee DB Username: (This is the mysql user will use to connect to the database)
usern="Asset_"
usern=$usern`tr -dc A-Za-z0-9_ < /dev/urandom | head -c 8 | xargs`

#Randomly Generate DB Pass: (This is the password that the MySQL user will use to connect to the database)
dbpass=`tr -dc A-Za-z0-9_ < /dev/urandom | head -c 16 | xargs`

#Randomly Generate DB READ ONLY Username: (This is the mysql user will use to connect to the database)
usernro="AssetRO_"
usernro=$usernro`tr -dc A-Za-z0-9_ < /dev/urandom | head -c 8 | xargs`

#Randomly Generate DB READ ONLY Pass: (This is the password that the MySQL user will use to connect to the database)
dbpassro=`tr -dc A-Za-z0-9_ < /dev/urandom | head -c 16 | xargs`

echo "MYSQL hostname (localhost): ";
read mysqlhost;
if [ "$mysqlhost" == "" ]; then
  mysqlhost="localhost";
fi

echo "MYSQL Username (root): ";
read myslquser;
if [ "$myslquser" == "" ]; then
  myslquser="root";
fi

echo "MYSQL root  Password: ";
stty -echo
read rpass;
stty echo

#COPY config template
cp config.orig.php config.php

Q1="CREATE DATABASE IF NOT EXISTS $dbname;"
Q2="GRANT ALL ON $dbname.* TO '$usern'@'$mysqlhost' IDENTIFIED BY '$dbpass';"
Q3="FLUSH PRIVILEGES;"
Q4="USE $dbname;"
SQL="${Q1}${Q4}${Q2}${Q3}"

SQLRO="GRANT SELECT ON $dbname.* TO '$usernro'@'$mysqlhost' IDENTIFIED BY '$dbpassro';"
SQLRO2="GRANT ALL ON $dbname.member_prefs TO $usernro IDENTIFIED BY '$dbpassro';"

REPLACEFIL=$(pwd);

echo $REPLACEFIL;

$MYSQL -h $mysqlhost -u $myslquser -p$rpass -e "$SQL";
$MYSQL -h $mysqlhost -u $myslquser -p$rpass $dbname < assetsetup.sql
$MYSQL -h $mysqlhost -u $myslquser -p$rpass -e "$SQLRO";
$MYSQL -h $mysqlhost -u $myslquser -p$rpass -e "$SQLRO2";

sed -i "s/replaceuser/$usern/g" config.php
sed -i "s/replacepass/$dbpass/g" config.php
sed -i "s/replacedb/$dbname/g" config.php
sed -i "s/roreplace/$usernro/g" config.php
sed -i "s/ropassreplace/$dbpassro/g" config.php
sed -i "s|replacefil|$REPLACEFIL|g" config.php
sed -i "s/mysqlserver/$mysqlhost/g" config.php